@@ -12,7 +12,7 @@ class Robot(URDFModel):
     Initializes a robot object, as defined by a single corresponding robot URDF
 
     Args:
-        fname (str): 
+        fname (str): path to the urdf file.
     """
     def __init__(
         self, 
@@ -30,11 +30,14 @@ class Robot(URDFModel):
         self.kin = None
         self._setup_kinematics()
 
-    def __repr__(self):
+    def __str__(self):
         return f"""ROBOT : {self.robot_name} 
         {self.links} 
         {self.joints}"""
 
+    def __repr__(self):
+        return 'pykin.robot.{}()'.format(type(self).__name__)
+
     @property
     def offset(self):
         return self._offset
@@ -44,6 +47,9 @@ class Robot(URDFModel):
         self._offset = offset
 
     def show_robot_info(self):
+        """
+        Shows robot's info 
+        """
         print("*" * 100)
         print(f"Robot Information: \n{self}")
         print(f"robot's dof : {self.dof}")
@@ -51,10 +57,23 @@ class Robot(URDFModel):
         print("*" * 100)
 
     def compute_pose_error(self, target=np.eye(4), result=np.eye(4)):
+        """
+        Computes pose error
+
+        Args:
+            target (np.array): target pose
+            result (np.array): result pose 
+
+        Returns:
+            error (np.array)
+        """
         error = np.linalg.norm(np.dot(result, np.linalg.inv(target)) - np.mat(np.eye(4)))
         return error
 
     def _setup_kinematics(self):
+        """
+        Sets instance of Kinematics
+        """
         self.kin = Kinematics(robot_name=self.robot_name,
                               offset=self.offset,
                               active_joint_names=self.get_actuated_joint_names(),
@@ -65,10 +84,20 @@ class Robot(URDFModel):
         self._init_transform()
         
     def _init_transform(self):
+        """
+        Initializes robot's transformation
+        """
         thetas = np.zeros(self.dof)
         self.kin.forward_kinematics(thetas)
 
     def set_desired_frame(self, base_name="", eef_name=None):
+        """
+        Sets robot's desired frame
+
+        Args:
+            base_name (str): reference link name
+            eef_name (str): end effector name
+        """
         self.kin.base_name = base_name
         self.kin.eef_name = eef_name
 
@@ -82,6 +111,9 @@ class Robot(URDFModel):
         self.kin.active_joint_names = self.get_actuated_joint_names(self.kin.frames)
 
     def reset_desired_frames(self):
+        """
+        Resets robot's desired frame
+        """
         self.kin.frames = self.root
         self.kin.active_joint_names = self.get_actuated_joint_names()
 
